==> Iacorner_0.22_dev.zip: an/db/hsql/sql/01_TABLE/AN03S.sql <==
/**************************************************************************/
/* AN03 ( アンケート項目詳細マスタ )                                      */
/*                                                                        */
/* Created : 2010/09/27 16:41:31                                          */
/**************************************************************************/
CREATE TABLE AN03 (
   USERID    VARCHAR(10)                  NOT NULL      /* 1  ユーザーID         */
 , CDANK     VARCHAR(10)                  NOT NULL      /* 2  アンケートC        */
 , CDSITSU   VARCHAR(10)                  NOT NULL      /* 3  質問C              */
 , KVAL      VARCHAR(4000)                NOT NULL      /* 4  回答値             */
 , SEQNO     INTEGER          DEFAULT 0   NOT NULL      /* 5  表示順             */
 , KNAME     VARCHAR(4000)                NOT NULL      /* 6  回答名称           */
 , IMGKVAL   VARCHAR(200)                               /* 7  回答値画像         */
 , IMGSKVAL  VARCHAR(10)                                /* 8  回答値画像(拡張子) */
 , FGOTHER   VARCHAR(1)       DEFAULT '0' NOT NULL      /* 9  その他F            */
 , RKCODE    VARCHAR(20)                                /* 10 連携用回答C        */
 , FGCORRECT VARCHAR(1)                                 /* 11 正解F              */
 , BIKO      VARCHAR(4000)                              /* 12 備考               */
 , UNIQ      IDENTITY                                   /* 13 ユニークキー       */
 , FGJ       VARCHAR(1)       DEFAULT '1' NOT NULL      /* 14 状態フラグ         */
 , DYSET     VARCHAR(14)                                /* 15 登録日時           */
 , PGSET     VARCHAR(10)                                /* 16 作成PG             */
 , PGPSET    VARCHAR(10)                                /* 17 作成親PG           */
 , USRSET    VARCHAR(10)                                /* 18 作成社員           */
 , DYUPD     VARCHAR(14)                                /* 19 更新日時           */
 , PGUPD     VARCHAR(10)                                /* 20 更新PG             */
 , PGPUPD    VARCHAR(10)                                /* 21 更新親PG           */
 , USRUPD    VARCHAR(10)                                /* 22 更新者             */
);

==> Iacorner_0.23_dev.zip: an/db/hsql/sql/01_TABLE/AN03S.sql <==
/**************************************************************************/
/* AN03 ( アンケート項目詳細マスタ )                                      */
/*                                                                        */
/* Created : 2010/10/08 09:29:32                                          */
/**************************************************************************/
CREATE TABLE AN03 (
   USERID    VARCHAR(10)                  NOT NULL      /* 1  ユーザーID         */
 , CDANK     VARCHAR(10)                  NOT NULL      /* 2  アンケートC        */
 , CDSITSU   VARCHAR(10)                  NOT NULL      /* 3  質問C              */
 , KVAL      VARCHAR(4000)                NOT NULL      /* 4  回答値             */
 , SEQNO     INTEGER          DEFAULT 0   NOT NULL      /* 5  表示順             */
 , KNAME     VARCHAR(4000)                NOT NULL      /* 6  回答名称           */
 , IMGKVAL   VARCHAR(200)                               /* 7  回答値画像         */
 , IMGSKVAL  VARCHAR(10)                                /* 8  回答値画像(拡張子) */
 , FGOTHER   VARCHAR(1)       DEFAULT '0' NOT NULL      /* 9  その他             */
 , RKCODE    VARCHAR(20)                                /* 10 連携用回答C        */
 , FGCORRECT VARCHAR(1)                                 /* 11 正解               */
 , BIKO      VARCHAR(4000)                              /* 12 備考               */
 , UNIQ      IDENTITY                                   /* 13 ユニークキー       */
 , FGJ       VARCHAR(1)       DEFAULT '1' NOT NULL      /* 14 状態フラグ         */
 , DYSET     VARCHAR(14)                                /* 15 登録日時           */
 , PGSET     VARCHAR(10)                                /* 16 作成PG             */
 , PGPSET    VARCHAR(10)                                /* 17 作成親PG           */
 , USRSET    VARCHAR(10)                                /* 18 作成社員           */
 , DYUPD     VARCHAR(14)                                /* 19 更新日時           */
 , PGUPD     VARCHAR(10)                                /* 20 更新PG             */
 , PGPUPD    VARCHAR(10)                                /* 21 更新親PG           */
 , USRUPD    VARCHAR(10)                                /* 22 更新者             */
);
